@@ -4,10 +4,11 @@
 #' @param age.col the number or name of \code{dat} column which have a \code{\link{numeric}} \code{\link{vector}} representing ages or stage categories.
 #' @param sex.col the number or name of \code{dat} column which have a \code{\link{factor}} with two levels representing the sex of individuals (see Details).
 #' @param str.col the number of \code{dat} column which have a \code{\link{factor}} representing the reproductive status of individuals (see Details).
-#' @param x.label a string to be used as a label for x-axis. If non defined, \code{x.label} is equal to "Total" (see Details).
+#' @param x.label string to be used as a label for x-axis. If non defined, \code{x.label} is equal to "Total" (see Details).
 #' @param stage.label a string to be used as a label for ages or stages categories. If non defined, \code{stage.label} is equal to "Years" (see Details).
 #' @param inner.color any valid way to specify colors. When \code{str.col} is \code{NULL}, \code{inner.color} is the color of bars. When \code{str.col} is not \code{NULL}, \code{innercolor} is the inner color of bars. If non defined, \code{inner.color} is equal to \code{"Gold2"}.
 #' @param outer.color any valid way to specify colors. When \code{str.col} is \code{NULL}, \code{outer.color} is ignored. When \code{str.col} is not \code{NULL}, \code{outer.color} is the outer color of bars. If non defined, \code{outercolor} is equal to \code{"DarkOliveGreen"}.
+#' @param label.size string to define the font size for labels.
 #' @details \code{PlotPopPyramid} is mainly intended for companion animals population pyramids, although it can display other types of opposed bar charts with suitable modification of the arguments.
 #' 
 #' The bars to the left of \code{0} on the x axis correspond to the minimum value of \code{\link{as.numeric}} (\code{dat[, sex.col]}). If \code{str.col} is not \code{NULL}, bars will be stacked, with the minimum value of \code{\link{as.numeric}}(\code{dat[, str.col]}) as their base.
@@ -32,7 +33,7 @@
 #' # PlotPopPyramid(survey.data, age.col = 5, sex.col = 4, str.col = 6)
 #' # PlotPopPyramid(survey.data, age.col = 5, sex.col = 4)
 #' 
-PlotPopPyramid <- function(dat = NULL, age.col = NULL, sex.col = NULL, str.col = NULL, x.label = 'Total', stage.label = 'Years', inner.color = 'Gold2', outer.color = 'DarkOliveGreen') {
+PlotPopPyramid <- function(dat = NULL, age.col = NULL, sex.col = NULL, str.col = NULL, x.label = 'Total', stage.label = 'Years', inner.color = 'Gold2', outer.color = 'DarkOliveGreen', label.size = 13) {
   if (!is.numeric(dat[, age.col])) {
     stop('The column containing age information must be numeric.')
   }
@@ -86,7 +87,9 @@ PlotPopPyramid <- function(dat = NULL, age.col = NULL, sex.col = NULL, str.col =
           axis.ticks.length = unit(0, 'lines'),
           axis.text.y = element_blank(),
           axis.title.y = element_blank(),
-          axis.text.x = element_text(size = 11)) +
+          axis.text.x = element_text(size = label.size),
+          axis.title.x = element_text(size = label.size),
+          plot.title = element_text(size = label.size)) +
     scale_x_continuous(breaks = 0:max(dat2$age),
                        labels = 0:max(dat2$age)) +
     scale_y_continuous(breaks = seq(0, (ylb * -1), by = ylb / -5),
@@ -101,9 +104,12 @@ PlotPopPyramid <- function(dat = NULL, age.col = NULL, sex.col = NULL, str.col =
           axis.ticks.length = unit(0, 'lines'),
           axis.text.y = element_blank(),
           axis.title.y = element_blank(),
-          axis.text.x = element_text(size = 11),
-          legend.title = element_text(size = 10),
-          legend.text = element_text(size = 10)) +
+          axis.text.x = element_text(size = label.size),
+          axis.title.x = element_text(size = label.size),
+          legend.title = element_text(face = 'plain',
+                                      size = label.size),
+          legend.text = element_text(size = label.size),
+          plot.title = element_text(size = label.size)) +
     scale_x_continuous(breaks = 0:max(dat2$age),
                        labels = 0:max(dat2$age)) +
     scale_y_continuous(breaks = seq(0, ylb, by = ylb / 5),
@@ -123,12 +129,15 @@ PlotPopPyramid <- function(dat = NULL, age.col = NULL, sex.col = NULL, str.col =
           plot.margin = unit(c(0.5, 0, 0.5, 0), "lines"),
           axis.ticks.length = unit(0, 'lines'),
           axis.text.y = element_blank(),
-          axis.title.y = element_blank()) +
+          axis.title.y = element_blank(),
+          axis.text.x = element_text(size = label.size),
+          axis.title.x = element_text(size = label.size),
+          plot.title = element_text(size = label.size)) +
     scale_y_continuous(breaks = 0, labels = '') +
     scale_x_continuous(breaks = 0:max(dat2$age),
                        labels = 0:max(dat2$age)) +
     annotate("text", y = 0, x = 0:max(dat2$age),
-             label = 0:max(dat2$age)) +
+             label = 0:max(dat2$age), size = label.size / 3) +
     ylab('') +
     ggtitle(stage.label)
   vplayout <- function(x, y) {
